import {Component, inject, Input, OnInit} from "@angular/core";
import {Hotel} from "./hotel"
import {CurrencyPipe, NgOptimizedImage} from "@angular/common";
import {Lang} from "../idek/lang";
import {StarComponent} from "../star/star.component";
import {ActivatedRoute} from "@angular/router";
import {HotelService} from "../service/hotel.service";
import {catchError, EMPTY, throwError} from "rxjs";


@Component({
  standalone: true,
  selector: 'app-hotel',
  imports: [
    CurrencyPipe,
    StarComponent,
    NgOptimizedImage
  ],
  template: `
    <div style="border: white 2px; border-radius: 2px">
      @if (hotel && !alert) {
        <p class="name">Name: {{ hotel.hotelName }}</p>
        <p>Beschreibung: {{ hotel.description }}</p>
        <p>Preis: {{ hotel.price | currency: currency.currency : 'symbol' : '2.2-2' : currency.code }}/nacht</p>
        <p>Sterne:
          <app-star [rating]="hotel.rating"></app-star>
        </p>
        <img width="64" height="64" src="{{hotel.imageUrl}}">
      } @else if(alert) {
        <h2>{{alert}}</h2>
      } @else {
        <h2>loading</h2>
      }

    </div>
  `
})
export class HotelComponent implements OnInit {
  protected currency: Lang = {name: 'de', code: 'de-DE', currency: 'EUR'}

  protected hotel!: Hotel;

  protected alert: string|undefined

  private route: ActivatedRoute = inject(ActivatedRoute);

  private hotelService: HotelService = inject(HotelService);

  ngOnInit(): void {
    const hotelId = this.route.snapshot.params['hotelId'];
    this.hotelService.getHotelById(hotelId)
      .pipe(catchError((err) => {
      this.alert = `Hotel could not be retrieved: ${err.message}`
      return EMPTY;
    }))
      .subscribe({next: (hotel: Hotel) => {this.hotel = hotel}})
  }
}
